<?php
/*--------------------------------------------------------------------------------------------------------------

	Plugin Name: Wolf Widgets Pack
	Plugin URI: http://wpwolf.com/wolf-widgets-pack
	Description: Includes 3 custom widgets : recent posts with thumbnail, recent comments with avatars and video widget
	Version: 1.0.1
	Author: Constantin Saguin
	Author URI: http://wpwolf.com/about/

----------------------------------------------------------------------------------------------------------------*/

class Wolf_Widgets_Pack {

	var $update_url = 'http://plugins.wpwolf.com/update';

	function __construct() {

		define( 'WOLF_WIDGETS_PACK_URL', plugins_url() . '/' . basename( dirname( __FILE__) ) );
		define( 'WOLF_WIDGETS_PACK_DIR', dirname( __FILE__ ) );

		// Load plugin text domain
		add_action( 'init', array( $this, 'plugin_textdomain' ) );

		// add widget thumbnails image sizes
		add_image_size( 'widget-thumb', 80, 80, true );

		// require widget files
		require_once( WOLF_WIDGETS_PACK_DIR . '/widgets/recent-posts-widget.php' );
		require_once( WOLF_WIDGETS_PACK_DIR . '/widgets/recent-comments-widget.php' );
		require_once( WOLF_WIDGETS_PACK_DIR . '/widgets/video-widget.php' );

		add_action( 'wp_print_styles', array( &$this, 'print_styles' ) );

		// update notification
		add_action( 'admin_init', array( &$this, 'plugin_update' ) );

	}

	// --------------------------------------------------------------------------

	/**
	 * Loads the plugin text domain for translation
	 */
	function plugin_textdomain() {

		$domain = 'wolf';
		$locale = apply_filters( 'wolf', get_locale(), $domain );
		load_textdomain( $domain, WP_LANG_DIR.'/'.$domain.'/'.$domain.'-'.$locale.'.mo' );
		load_plugin_textdomain( $domain, FALSE, dirname( plugin_basename( __FILE__ ) ) . '/lang/' );

	}

	// --------------------------------------------------------------------------

	/**
	 * Print Styles
	 */
	function print_styles() {
		wp_register_style( 'wolf-widgets-pack', WOLF_WIDGETS_PACK_URL.'/css/widgets.css',array(), '0.1', 'all' );
		wp_enqueue_style( 'wolf-widgets-pack' );
	}

	// --------------------------------------------------------------------------

	/**
	 * Plugin update
	 */
	function plugin_update() {
		
		$plugin_data = get_plugin_data( __FILE__ );

		$current_version = $plugin_data['Version'];
		$plugin_slug = plugin_basename( dirname( __FILE__ ) );
		$plugin_path = plugin_basename( __FILE__ );
		$remote_path = $this->update_url . '/' . $plugin_slug;
		
		if ( ! class_exists( 'Wolf_WP_Update' ) )
			include_once( 'class/class-wp-update.php' );
		
		new Wolf_WP_Update( $current_version, $remote_path, $plugin_path );
	}

}

new Wolf_Widgets_Pack;


if ( ! function_exists( 'wolf_widgets_pack_sample' ) ):
/**
 * Returns a sample from a string
 */
function wolf_widgets_pack_sample( $text, $nbcar = 200 ){   
	
	$text= strip_tags( $text );   
	
	if ( strlen( $text ) > $nbcar) {
		
		preg_match( '!.{0,'.$nbcar.'}\s!si', $text, $match );
		if ( isset( $match[0] ) )
			$str = trim( $match[0] ) . '...';
		else
			$str = $text; 

	} else {
		$str = $text;  
	}
	
	$str = preg_replace( '/\s\s+/', '', $str );
	$str = preg_replace( '|\[(.+?)\](.+?\[/\\1\])?|s', '', $str );

	return $str;
}
endif;
?>