/**
 * Functionality specific to the theme
 *
 */
;( function( $ ) {

	'use strict';

	var body = $( 'body' ),
		page = $( '#page' ),
		overlay = $( '#overlay' ),
		loader = $( '#loader' ),
		header = $( '#masthead' ),
		topBar = $( '#top-bar' ),
		navbarContainer = $( '#navbar-container' ),
		navbarOffset  = -1,
		toolbarOffset = body.is( '.admin-bar' ) ? 28 : 0,
		clock = 0,
		isMobile = navigator.userAgent.match( /(iPad)|(iPhone)|(iPod)|(Android)|(PlayBook)|(BB10)|(BlackBerry)|(Opera Mini)|(IEMobile)|(webOS)|(MeeGo)/i );

	// timer to display the loader if loading during more than 1 sec
	var timer = setInterval( function() {
		clock++; 
		// console.log(clock);
		if ( clock === 1 ) {
			$( '#loader' ).fadeIn();
		}

		/* 
		If the loading time is more than 5sec, we hide the overlay anyway 
		An iframe such as a video or a google map probably takes too much time to load
		So let's show the page
		*/
		if ( clock === 2 ) {
			hideOverlay();
		}
	}, 1000 );

	
	if ( isMobile ) {
		$( 'body' ).addClass( 'is-mobile' );
	}

	/**
	 * Repositions the window on jump-to-anchor to account for
	 * navbar height.
	 */
	var WolfAdjustAnchor = function() {
		if ( window.location.hash )
			window.scrollBy( 0, -80 );
	};

	$( document ).on( 'ready',    WolfAdjustAnchor );
	$( window ).on( 'hashchange', WolfAdjustAnchor );


	// --------------------------------------------------------------------------

	/**
	 * Displays the fixed navbar based on screen position.
	 */
	function stickyNav( posScroll ){
		var pageMarginTop = parseInt( page.css( 'marginTop' ) );
		
		navbarOffset = topBar.outerHeight() + header.outerHeight() + pageMarginTop - navbarContainer.outerHeight() - toolbarOffset;

		if ( posScroll >= Math.floor( navbarOffset ) && 767 < window.innerWidth ) {
			body.addClass( 'navbar-fixed' );
		} else {
			body.removeClass( 'navbar-fixed' );
		}			
	}

	// --------------------------------------------------------------------------

	/**
	 * Enables menu toggle for small screens.
	 */
	( function() {

		var nav = $( '#site-navigation-primary' ), button, menu;

		if ( ! nav ) {
			return;
		}
			
		button = $( '.menu-toggle' );
		menu = nav.find( '.nav-menu' );
		if ( ! button ) {
			return;
		}

		// Hide button if menu is missing or empty.
		if ( ! menu || ! menu.children().length ) {
			button.hide();
			return;
		}

		
		$( '.menu-toggle' ).on( 'click', function() {
			nav.toggleClass( 'toggled-on' );
		} );

	} )();


	// --------------------------------------------------------------------------

	/**
	 * Fluid Video wrapper
	 */
	var videoSelectors = [
		"iframe[src*='player.vimeo.com']",
		"iframe[src*='youtube.com']",
		"iframe[src*='youtube-nocookie.com']",
		"iframe[src*='kickstarter.com'][src*='video.html']",
		"iframe[src*='screenr.com']",
		"iframe[src*='blip.tv']",
		"iframe[src*='dailymotion.com']",
		"iframe[src*='viddler.com']",
		"iframe[src*='qik.com']",
		"iframe[src*='revision3.com']",
		"iframe[src*='hulu.com']",
		"iframe[src*='funnyordie.com']",
		"iframe[src*='flickr.com']",
		"embed[src*='v.wordpress.com']"
	];

	var allVideos = videoSelectors.join(',');
	$( '#page' ).find( allVideos ).wrap( '<span class="fluid-video" />' );
	$( '.rev_slider_wrapper' ).find( allVideos ).unwrap();


	/**
	 * Fix video z-index bug
	 */
	var iframes = $( 'iframe' );

	if ( iframes.length ) {

		iframes.each(function(){
			
			var url = $( this ).attr( 'src' );

			if ( url.match( /(youtube.com)|(youtu.be)/i ) ) {
				
				if ( url.indexOf( '?' ) !== -1) {

					$( this ).attr( 'src', url + '&wmode=transparent' );

				} else {

					$( this ).attr('src', url + '?wmode=transparent' );

				}
			}
			
				
		} );

	}

	// --------------------------------------------------------------------------

	/**
	 * Share Links Popup
	 */
	$( ".share-link" ).click( function() {
		var $this = $( this);
		if ( $this.data( 'popup' ) === true && ! isMobile ){
			var url = $( this ).attr( "href" );
			var height = $this.data( 'height' ) || 250;
			var width = $this.data( 'width' ) || 500;
			var popup = window.open( url,"null", "height=" + height + ",width=" + width + ", top=150, left=150" );
			if ( window.focus ) {
				popup.focus();
			}
			return false; 
		}
	});

	// --------------------------------------------------------------------------

	/**
	 * Lightbox
	 */
	if ( $.isFunction( $.swipebox ) && WolfThemeParams.lightbox === 'swipebox' ) {
				
		$( '.lightbox, .wolf-show-flyer, .wolf-show-flyer-single, .last-photos-thumbnails' ).swipebox();

		if ( WolfThemeParams.videoLightbox !== null ) {
			$( '.video-item-container .entry-link' ).swipebox();
		}
	

	} else if ( $.isFunction( $.fancybox ) && WolfThemeParams.lightbox === 'fancybox' ) {

		$( '.lightbox, .wolf-show-flyer, .wolf-show-flyer-single, .last-photos-thumbnails' ).fancybox();

		if ( WolfThemeParams.videoLightbox !== null ) {
			$( '.video-item-container .entry-link' ).fancybox( {
				padding : 0,
				nextEffect : 'none',
				prevEffect : 'none',
				openEffect  : 'none',
				closeEffect : 'none',
				helpers : {
					media : {},
					title : {
						type : 'outside'
					},
					overlay : {
						opacity: 0.9
					}
				}
			} );
		}
	}

	/**
	 * Add replace entry link by video link
	 */
	if ( $( '.video-item-container' ).length && WolfThemeParams.videoLightbox !== null && WolfThemeParams.lightbox !== 'none' ) {
		
		var videoItem = $( '.video-item-container' ),
			postId,
			data;

		videoItem.each( function() {

			var _this = $( this );

			postId = _this.attr( 'id' ).replace( 'post-', '' );

			data = {
				action: 'wolf_get_video_url_from_post_id',
				id : postId
			};
			
			$.post( WolfThemeParams.ajaxUrl , data, function(response){
				
				// console.log( response );
				if ( response ) {
					_this.find( '.entry-link' ).attr( 'href', response );
				}

			});
		} );

		$( '.video-item-container .entry-link' ).each( function(){ $( this ).attr( 'rel','video-gallery' ); } );
	}

	$( '.gallery .lightbox' ).each( function(){ $( this ).attr( 'rel','gallery' ); } );


	// --------------------------------------------------------------------------

	$( '.scroll' ).bind( 'click',function( event ) {
		var $anchor = $( this );                 
		var scrollOffset = body.hasClass( 'sticky-menu' ) ? toolbarOffset*2 : toolbarOffset;
		$( 'html, body' ).stop().animate({
			scrollTop: $( $anchor.attr( 'href' ) ).offset().top - scrollOffset
		}, 1E3, 'swing' );
		event.preventDefault();
	} );

	
	// --------------------------------------------------------------------------

	/**
	 * Bottom Area
	 * If a google map is displayed, make it full width
	 */
	if ( $( '#bottom-holder .wolf-google-map' ).length || $( '#bottom-holder iframe[src^="https://maps.google"]' ).length ){
		$( '#bottom-holder' ).css({ padding : 0 });
		$( '#bottom-holder .wrap' ).css({ 'overflow' : 'hidden', 'max-width' : '100%', width : '100%', height : $( '#bottom-holder iframe[src^="https://maps.google"]' ).height() });
		$( '#bottom-holder .wrap p' ).remove();
	}

	// --------------------------------------------------------------------------

	/**
	 * MailChimp Custom Form
	 */
	if ( $( '.wolf-widget-area .wolf_widget_col_12.widget_mailchimpsf_widget' ).length ) {
		//var label = $( '.mc_header_email' ).text();
		var input = $( '#mc_mv_EMAIL' ); 
		if ( input.attr( 'placeholder' ) === '' ) {
			input.attr( 'placeholder', WolfThemeParams.newsletterPlaceholder );
		}
	}

	// --------------------------------------------------------------------------

	
	/**
	 *  Parallax
	 */
	function parallax() {
		if ( ! isMobile && 799 < $( window ).width() ) {
			$(' .section-parallax' ).each( function() {
				$( this ).parallax( "50%", 0.1 );
			} );	
		}
	}


	// --------------------------------------------------------------------------

	/**
	 * Center the main menu
	 */
	function centerMenu() {

		var breakpoint = WolfThemeParams.menuBreakPoint;
				
		if ( ( breakpoint < $( window ).width() && body.hasClass( 'center-menu' ) ) || ( body.hasClass( 'no-mobile-menu' ) && body.hasClass( 'center-menu' ) ) ) {
			
			var leftPos =  ( $( '#navbar' ).width() - $( '#site-navigation-primary .nav-menu' ).width() )/2;
			$( '#site-navigation-primary .nav-menu' ).css(  { 'marginLeft' :  Math.floor( leftPos ) + 'px', 'float' : 'left' } );

		} else {
			$( '#site-navigation-primary .nav-menu' ).css(  { 'marginLeft' :  '0', 'float' : 'none' } );
		}

	}
	centerMenu();


	// --------------------------------------------------------------------------


	/**
	 *  Add menu breakpoint class
	 */
	function breakPoint() {

		var breakpoint = WolfThemeParams.menuBreakPoint;
				
		if ( breakpoint > $( window ).width() && ! body.hasClass( 'no-mobile-menu' ) ) {
			body.addClass( 'menu-breakpoint' );
		} else {
			body.removeClass( 'menu-breakpoint' );
		}

	}

	// --------------------------------------------------------------------------

	/**
	 * Back to the top link animation
	 */
	function topLinkAnimation( posScroll ){

		var scrollBottom = posScroll + $(window).height();
		var bottomOffset = $('.site-infos').length ? ( $('.site-infos').outerHeight() + $( '#site-navigation-tertiary' ).outerHeight() ) : $( '#site-navigation-tertiary' ).outerHeight();
		
		if ( posScroll >=550 ) {
			$('a#top-arrow').show();
		} else {
			$('a#top-arrow').hide();
		}
				

		if ( scrollBottom >= $( '#site-navigation-tertiary' ).offset().top && 767 < window.innerWidth && ! body.hasClass( 'boxed' ) ) {
			$( 'a#top-arrow' ).css( { position : 'absolute', bottom : bottomOffset } );
		} else {
			$( 'a#top-arrow' ).css({ position : 'fixed', bottom : 0 });
		}			
	}

	// --------------------------------------------------------------------------


	/**
	 * WooCommerce Fix.
	 */
	$( '.products li' ).removeClass( 'first last' );

	if ( $( '.woocommerce-pagination' ).length ) {
		$( '.woocommerce-pagination' ).removeClass( 'woocommerce-pagination' );
	}

	// --------------------------------------------------------------------------

	/**
	 * IE8 fix - Add "last-child" class
	 */
	$( '.ie8 .sidebar-footer .widget-area .widget:last-child, .ie8 .widget-area .widget:last-child' ).addClass( 'last-child' );

	// --------------------------------------------------------------------------
	

	/**
	 * Resize event
	 */
	$( window ).resize( function() {
		parallax();
		breakPoint();
		centerMenu();
	}).resize();

	// --------------------------------------------------------------------------


	/**
	 * Scroll event
	 */
	$(window ).scroll( function() {
		stickyNav( $( window ).scrollTop() );
		topLinkAnimation( $( window ).scrollTop() );
	});

	/**
	 * Hide Overlay
	 */
	function hideOverlay() {
		loader.fadeOut( 'fast', function() {

			overlay.fadeOut( 'slow', function() {
				clearInterval( timer );
			} );
			
		} );
	}



	// --------------------------------------------------------------------------

	/**
	 * Load event
	 */
	$( window ).load( function() {

		/**
		 * Hide loader overlay if visible
		 */
		if ( overlay.is( ':visible' ) ) {
			hideOverlay();
		}
		

		/**
		 * FlexSlider
		 */
		if ( $.isFunction( $.flexslider ) ) {

			/* Post slider */
			$( '.format-gallery .flexslider' ).flexslider( {
				animation: 'slide',
				slideshow : true,
				smoothHeight : true
			} );

		}

		parallax();
	} );


} )( jQuery );