/**
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 * Things like site title, description, and background color changes.
 */

( function( $ ) {

	/**
	 * Background
	 */
	var backgrounds = {
		'body_bg' : 'body',
		'page_bg' : '#main, #intro',
		'menu_bg' : '#navbar-container',
		'header_bg' : '.site-header',
		'entry_bg' : '.entry-content, #comments-container, #secondary .widget, #container',
		'top_holder_bg' : '#top-holder',
		'bottom_holder_bg' : '#bottom-holder',
		'sidebar_footer_bg' : '.sidebar-footer',
		'music_network_bg' : '.wolf-music-social-icons-container'
	};
	var options = [ 'repeat', 'position', 'attachment' ];


	$.each( backgrounds, function( key, bg ) {

		$.each( options, function( k, o ) {

			wp.customize( key + '_' + o, function( value ) {

				value.bind( function( to ) {

					var prop = 'background-' + o;
					$( bg ).css( prop , to );

				} );
			} );

		} );

		/* Color
		---------------*/
		// alert( $(bg).css( 'background-color' ) );

		/* Size
		---------------*/
		wp.customize( key + '_size', function( value ) {
			value.bind( function( to ) {

				if ( to === 'cover' ) {
					$( bg ).css( {
						'background-size' : 'cover',
						'-webkit-background-size' : 'cover',
						'-moz-background-size' : 'cover',
						'-o-background-size' : 'cover'
					} );

				} else if ( to === 'resize' ) {

					$( bg ).css( {
						'background-size' : '100% auto',
						'-webkit-background-size' : '100% auto',
						'-moz-background-size' : '100% auto',
						'-o-background-size' : '100% auto'
					} );

				} else {
					$( bg ).css( {
						'background-size' : 'auto',
						'-webkit-background-size' : 'auto',
						'-moz-background-size' : 'auto',
						'-o-background-size' : 'auto'
					} );
				}
			} );

		} );

	} ); // end for each background


	// --------------------------------------------------------------------------

	wp.customize( 'page_container', function( value ) {
		value.bind( function( to ) {
			$( 'body' ).removeClass( 'boxed fullwidth' );
			$( 'body' ).addClass( to );
		} );
	} );

	// --------------------------------------------------------------------------

	wp.customize( 'menu_position', function( value ) {
		value.bind( function( to ) {
			if ( to === 'bottom' ) {

				$( '.site-header' ).css( {
					'padding-top' : '0',
					'padding-bottom' : '80px'

				} );

				$( '#navbar-container' ).css( {
					'bottom' : '0',
					'top' : 'auto'
				} );

			} else if ( to === 'top' ) {

				$( '.site-header' ).css( {
					'padding-bottom' : '0',
					'padding-top' : '80px'

				} );

				$( '#navbar-container' ).css( {
					'top' : '0',
					'bottom' : 'auto'
				} );
			}
		} );
	} );

	// --------------------------------------------------------------------------

	wp.customize( 'sticky_menu', function( value ) {
		value.bind( function( to ) {
			if ( to === true ) {

				$( 'body' ).addClass( 'sticky-menu' );

			} else if ( to === false ) {

				$( 'body' ).removeClass( 'sticky-menu' );
			}
		} );
	} );

	// --------------------------------------------------------------------------

	// wp.customize( 'center_menu', function( value ) {
	// 	value.bind( function( to ) {
	// 		if ( to === true ) {

	// 			$( 'body' ).addClass( 'center-menu' );

	// 		} else if ( to === false ) {

	// 			$( 'body' ).removeClass( 'center-menu' );
	// 		}
	// 	} );
	// } );

	// --------------------------------------------------------------------------

	wp.customize( 'hide_top_bar', function( value ) {
		value.bind( function( to ) {
			if ( to === true ) {

				$( '#top-bar' ).hide();

			} else if ( to === false ) {

				$( '#top-bar' ).show();
			}
		} );
	} );

	// --------------------------------------------------------------------------

	// wp.customize( 'main_menu_margin_left', function( value ) {
	// 	value.bind( function( to ) {
	// 		$( '.main-navigation' ).css( 'padding-left', to + 'px' );
	// 	} );
	// } );

	// --------------------------------------------------------------------------

	wp.customize( 'page_title_color', function( value ) {
		value.bind( function( to ) {
			$( '.error404, #intro' ).css( 'color', to );
		} );
	} );

	// --------------------------------------------------------------------------

	wp.customize( 'header_height', function( value ) {
		value.bind( function( to ) {
			$( '.site-header' ).css( 'min-height', to + 'px' );
		} );
	} );

	// --------------------------------------------------------------------------

	wp.customize( 'logo_align', function( value ) {
		value.bind( function( to ) {
			$( '#logo-container' ).css( { 'text-align' : to } );
		} );
	} );

} )( jQuery );
